@@ -1,6 +1,6 @@
+import importlib
 from typing import Any
 
-
 def get_connector(client: str) -> Any:
     """
     This function returns a client from a database according to package
@@ -11,24 +11,16 @@ def get_connector(client: str) -> Any:
     Raises:
         NotImplementedError: in the absence of a customer
         ModuleNotFoundError: the package is not installed
-        TypeError: [description]
+        TypeError: The argument is empty or the type is incorrect
 
     Returns: A client of the package that is passed by parameter
     """
     if isinstance(client, str) and client:
         try:
-            if client == "pymysql":
-                from pymysql import connect
-
-                return connect
-            elif client == "mysql.connector":
-                from mysql.connector import connect
-
-                return connect
+            if client in ["pymysql", "mysql.connector"]:
+                return getattr(importlib.import_module(client), "connect")
             elif client == "pymongo":
-                from pymongo import MongoClient
-
-                return MongoClient
+                return getattr(importlib.import_module(client), "MongoClient")
             else:
                 raise NotImplementedError
         except ModuleNotFoundError:
@@ -37,3 +29,27 @@ def get_connector(client: str) -> Any:
     raise TypeError(
         "The argument 'client' must be of type 'string' and must not be empty."
     )
+
+def get_cursor(client: str) -> Any:
+    """
+    This function return a client with cursor according to package
+
+    Args:
+        client (str): the package to use, e.g.: mysql.connector
+
+    Raises:
+        NotImplementedError: in the absence of a customer
+        TypeError: The argument is empty or the type is incorrect
+
+    Returns:
+        Any: A client with cursor
+    """
+    if isinstance(client, str) and client:
+        if client == "pymysql":
+            client += ".cursors"
+            return getattr(importlib.import_module(client), "DictCursor")
+        else:
+            raise NotImplementedError
+    raise TypeError(
+        "The argument 'client' must be of type 'string' and must not be empty."
+    )
\ No newline at end of file
